==> dependency-cruiser-1.2.1.tgz: package/test/validate.ruleSetNormalizer.js <==
"use strict";
const expect     = require('chai').expect;
const normalizer = require('../src/validate/ruleSetNormalizer');

describe("validator", () => {
    it("leaves the empty ruleset alone", () => {
        expect(normalizer.normalize({})).to.deep.equal({});
    });

    it("adds defaults for level and warning when they're not filled", () => {
        expect(normalizer.normalize({
            "allowed": [{
                "from": ".+",
                "to": ".+"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "level": "warning",
                "name": "unnamed"
            }]
        });
    });

    it("corrects the level to a default when it's not a recognized one", () => {
        expect(normalizer.normalize({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "level": "unrecognized",
                "name": "all-ok"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "level": "warning",
                "name": "all-ok"
            }]
        });
    });

    it("keeps the level if it's a recognized one", () => {
        expect(normalizer.normalize({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "level": "error",
                "name": "all-ok"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "level": "error",
                "name": "all-ok"
            }]
        });
    });

    it("also works for 'forbidden' rules", () => {
        expect(normalizer.normalize({
            "forbidden": [{
                "from": ".+",
                "to": ".+",
                "level": "error",
                "name": "all-ok",
                "comment": "this comment is kept"
            }]
        })).to.deep.equal({
            "forbidden": [{
                "from": ".+",
                "to": ".+",
                "level": "error",
                "name": "all-ok",
                "comment": "this comment is kept"
            }]
        });
    });
});

==> dependency-cruiser-1.5.1.tgz: package/test/validate.ruleSetNormalizer.js <==
"use strict";
const expect     = require('chai').expect;
const normalizer = require('../src/validate/ruleSetNormalizer');

describe("validator", () => {
    it("leaves the empty ruleset alone", () => {
        expect(normalizer({})).to.deep.equal({});
    });

    it("adds defaults for severity and warn when they're not filled", () => {
        expect(normalizer({
            "allowed": [{
                "from": ".+",
                "to": ".+"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "severity": "warn",
                "name": "unnamed"
            }]
        });
    });

    it("corrects the severity to a default when it's not a recognized one", () => {
        expect(normalizer({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "severity": "unrecognized",
                "name": "all-ok"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "severity": "warn",
                "name": "all-ok"
            }]
        });
    });

    it("keeps the severity if it's a recognized one", () => {
        expect(normalizer({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "severity": "error",
                "name": "all-ok"
            }]
        })).to.deep.equal({
            "allowed": [{
                "from": ".+",
                "to": ".+",
                "severity": "error",
                "name": "all-ok"
            }]
        });
    });

    it("also works for 'forbidden' rules", () => {
        expect(normalizer({
            "forbidden": [{
                "from": ".+",
                "to": ".+",
                "severity": "error",
                "name": "all-ok",
                "comment": "this comment is kept"
            }]
        })).to.deep.equal({
            "forbidden": [{
                "from": ".+",
                "to": ".+",
                "severity": "error",
                "name": "all-ok",
                "comment": "this comment is kept"
            }]
        });
    });
});
